@@ -55,7 +55,7 @@ def uri_connect(host: str = 'localhost', port: int = 27017, replicaset: str = No
     host = host[:-1] + f':{port}' + '/' if port else host
     uri += f'@{host}' if user and mode not in [Mode.MONGODB_AWS] else host
     if mode and mode.value:
-        uri += f'?authMechanism={mode.value}' + \
+        uri += (f'?authMechanism={mode.value}' if mode != Mode.URI else '') + \
             (f'&authMechanismProperties={session_token}' if session_token else '')
 
     if cert_key_file:
